==> ejc-doc-impl-3.0.0-20201128.062520-6-sources.jar: com/ejianc/business/doc/service/impl/DocCategoryRoleRelationServiceImpl.java <==
package com.ejianc.business.doc.service.impl;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.doc.bean.DocCategoryEntity;
import com.ejianc.business.doc.bean.DocCategoryRoleRelationEntity;
import com.ejianc.business.doc.mapper.DocCategoryRoleRelationMapper;
import com.ejianc.business.doc.service.IDocCategoryRoleRelationService;
import com.ejianc.business.doc.service.IDocCategoryService;
import com.ejianc.business.doc.vo.DocCategoryRoleRelationVO;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

/**
 * 文档分类角色关系
 * 
 * @author generator
 * 
 */
@Service("docCategoryRoleRelationService")
public class DocCategoryRoleRelationServiceImpl extends BaseServiceImpl<DocCategoryRoleRelationMapper, DocCategoryRoleRelationEntity> implements IDocCategoryRoleRelationService{

	@Autowired
	private DocCategoryRoleRelationMapper docCategoryMapper;
	@Autowired
	private IDocCategoryService docCategoryService;
	
	

	@Override
	public CommonResponse<String> saveDocCategoryRole(List<DocCategoryRoleRelationVO> relationList) {
		List<DocCategoryRoleRelationEntity> addList = new ArrayList<>();
		String roleName = "";
		//1、判重
		QueryWrapper<DocCategoryRoleRelationEntity> queryWrapper = new QueryWrapper<>();
		queryWrapper.eq("category_id", relationList.get(0).getCategoryId());
		queryWrapper.eq("dr", 0);
		List<DocCategoryRoleRelationEntity> list = this.list(queryWrapper);
		Map<Long,DocCategoryRoleRelationEntity> map = new HashMap<>();
		if(list!=null&&list.size()>0){
			for(DocCategoryRoleRelationEntity relation : list){
				map.put(relation.getRoleId(), relation);
				if(roleName.length()>0){
					roleName += ("、"+relation.getRoleName());
				}else{
					roleName += relation.getRoleName();
				}
			}
		}
		String message = "";
		for(DocCategoryRoleRelationVO vo : relationList){
			if(map.get(vo.getRoleId())==null){
				addList.add(BeanMapper.map(vo, DocCategoryRoleRelationEntity.class));
			}else{
				if(message.length()>0){
					message += ("、"+vo.getRoleName());
				}else{
					message += vo.getRoleName();
				}
			}
		}
		//2、保存
		if(addList.size()>0){
			this.saveOrUpdateBatch(addList, addList.size(), false);
			for(DocCategoryRoleRelationEntity relation : addList){
				map.put(relation.getRoleId(), relation);
				if(roleName.length()>0){
					roleName += ("、"+relation.getRoleName());
				}else{
					roleName += relation.getRoleName();
				}
			}
			DocCategoryEntity categoryEntity = docCategoryService.getById(relationList.get(0).getCategoryId());
			categoryEntity.setRoleName(roleName);
			docCategoryService.saveOrUpdate(categoryEntity, false);
			if(addList.size()!=relationList.size()){
				//有重复数据
				return CommonResponse.success("添加成功,其中以下角色："+message+"已存在");
			}
		}else{
			return CommonResponse.success("选择的角色都已在该分类下，请重新选择");
		}
		
		//
		return CommonResponse.success("添加成功");
	}

	@Override
	public CommonResponse<String> deleteDocCategoryRole(List<DocCategoryRoleRelationVO> relationList) {
		List<Long> ids = new ArrayList<>();
		for(DocCategoryRoleRelationVO vo : relationList){
			ids.add(vo.getId());
		}
		this.removeByIds(ids, false);

		String roleName = "";
		QueryWrapper<DocCategoryRoleRelationEntity> queryWrapper = new QueryWrapper<>();
		queryWrapper.eq("category_id", relationList.get(0).getCategoryId());
		queryWrapper.eq("dr", 0);
		List<DocCategoryRoleRelationEntity> list = this.list(queryWrapper);
		if(list!=null&&list.size()>0){
			for(DocCategoryRoleRelationEntity relation : list){
				if(roleName.length()>0){
					roleName += ("、"+relation.getRoleName());
				}else{
					roleName += relation.getRoleName();
				}
			}
		}

		DocCategoryEntity categoryEntity = docCategoryService.getById(relationList.get(0).getCategoryId());
		categoryEntity.setRoleName(roleName);
		docCategoryService.saveOrUpdate(categoryEntity, false);
		return CommonResponse.success("删除成功");
	}
	
}

==> ejc-doc-impl-3.0.0-20201204.085752-13-sources.jar: com/ejianc/business/doc/service/impl/DocCategoryRoleRelationServiceImpl.java <==
package com.ejianc.business.doc.service.impl;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.doc.bean.DocCategoryEntity;
import com.ejianc.business.doc.bean.DocCategoryRoleRelationEntity;
import com.ejianc.business.doc.mapper.DocCategoryRoleRelationMapper;
import com.ejianc.business.doc.service.IDocCategoryRoleRelationService;
import com.ejianc.business.doc.service.IDocCategoryService;
import com.ejianc.business.doc.vo.DocCategoryRoleRelationVO;
import com.ejianc.framework.cache.redis.CacheManager;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.util.ResultAsTree;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import redis.clients.jedis.Jedis;

/**
 * 文档分类角色关系
 * 
 * @author generator
 * 
 */
@Service("docCategoryRoleRelationService")
public class DocCategoryRoleRelationServiceImpl extends BaseServiceImpl<DocCategoryRoleRelationMapper, DocCategoryRoleRelationEntity> implements IDocCategoryRoleRelationService{

	@Autowired
	private DocCategoryRoleRelationMapper docCategoryMapper;
	@Autowired
	private IDocCategoryService docCategoryService;
	@Autowired
	private CacheManager cacheManager;
	//当前用户的角色KEY
	private final static String CURRENTUSER_ROLE_KEY = "currentuser_role_key:";
	
	
	@Override
	public CommonResponse<String> saveDocCategoryRole(List<DocCategoryRoleRelationVO> relationList) {
		List<DocCategoryRoleRelationEntity> addList = new ArrayList<>();
		String roleName = "";
		//1、判重
		QueryWrapper<DocCategoryRoleRelationEntity> queryWrapper = new QueryWrapper<>();
		queryWrapper.eq("category_id", relationList.get(0).getCategoryId());
		queryWrapper.eq("dr", 0);
		List<DocCategoryRoleRelationEntity> list = this.list(queryWrapper);
		Map<Long,DocCategoryRoleRelationEntity> map = new HashMap<>();
		if(list!=null&&list.size()>0){
			for(DocCategoryRoleRelationEntity relation : list){
				map.put(relation.getRoleId(), relation);
				if(roleName.length()>0){
					roleName += ("、"+relation.getRoleName());
				}else{
					roleName += relation.getRoleName();
				}
			}
		}
		String message = "";
		for(DocCategoryRoleRelationVO vo : relationList){
			if(map.get(vo.getRoleId())==null){
				addList.add(BeanMapper.map(vo, DocCategoryRoleRelationEntity.class));
			}else{
				if(message.length()>0){
					message += ("、"+vo.getRoleName());
				}else{
					message += vo.getRoleName();
				}
			}
		}
		//2、保存
		if(addList.size()>0){
			this.saveOrUpdateBatch(addList, addList.size(), false);
			for(DocCategoryRoleRelationEntity relation : addList){
				map.put(relation.getRoleId(), relation);
				if(roleName.length()>0){
					roleName += ("、"+relation.getRoleName());
				}else{
					roleName += relation.getRoleName();
				}
			}
			DocCategoryEntity categoryEntity = docCategoryService.getById(relationList.get(0).getCategoryId());
			categoryEntity.setRoleName(roleName);
			docCategoryService.saveOrUpdate(categoryEntity, false);
			if(addList.size()!=relationList.size()){
				//有重复数据
				return CommonResponse.success("添加成功,其中以下角色："+message+"已存在");
			}
		}else{
			return CommonResponse.success("选择的角色都已在该分类下，请重新选择");
		}
		
		//
		return CommonResponse.success("添加成功");
	}

	@Override
	public CommonResponse<String> deleteDocCategoryRole(List<DocCategoryRoleRelationVO> relationList) {
		List<Long> ids = new ArrayList<>();
		for(DocCategoryRoleRelationVO vo : relationList){
			ids.add(vo.getId());
		}
		this.removeByIds(ids, false);

		String roleName = "";
		QueryWrapper<DocCategoryRoleRelationEntity> queryWrapper = new QueryWrapper<>();
		queryWrapper.eq("category_id", relationList.get(0).getCategoryId());
		queryWrapper.eq("dr", 0);
		List<DocCategoryRoleRelationEntity> list = this.list(queryWrapper);
		if(list!=null&&list.size()>0){
			for(DocCategoryRoleRelationEntity relation : list){
				if(roleName.length()>0){
					roleName += ("、"+relation.getRoleName());
				}else{
					roleName += relation.getRoleName();
				}
			}
		}

		DocCategoryEntity categoryEntity = docCategoryService.getById(relationList.get(0).getCategoryId());
		categoryEntity.setRoleName(roleName);
		docCategoryService.saveOrUpdate(categoryEntity, false);
		return CommonResponse.success("删除成功");
	}

	@SuppressWarnings("rawtypes")
	@Override
	public CommonResponse<JSONObject> getListByUserId(Long userId) {
		if(userId == null)
			userId = InvocationInfoProxy.getUserid();
		JSONObject jsonObject = new JSONObject();
		//获取当前用户的角色
		List<Long> roleList = this.getUserRoleCache(userId);
		//获取有角色权限的分类
		QueryWrapper<DocCategoryRoleRelationEntity> queryWrapper = new QueryWrapper<>();
		queryWrapper.in("role_id", roleList);
		queryWrapper.eq("dr", 0);
		List<DocCategoryRoleRelationEntity> list = this.list(queryWrapper);
		if(list!=null&&list.size()>0){
			List<Long> categoryIds = new ArrayList<>();
			for(DocCategoryRoleRelationEntity entity : list){
				categoryIds.add(entity.getCategoryId());
			}
			QueryWrapper<DocCategoryEntity> wrapper = new QueryWrapper<>();
			wrapper.eq("dr", 0);
			wrapper.in("id", categoryIds);
			List<DocCategoryEntity> docCategoryList = docCategoryService.list(wrapper);
			List<Map> resultMapList = BeanMapper.mapList(docCategoryList, Map.class);
			jsonObject.put("data", ResultAsTree.createTreeData(resultMapList));
		}else{
			jsonObject.put("data", null);
		}
		
		return CommonResponse.success("查询列表数据成功！",jsonObject);
	}

	@Override
	public List<DocCategoryEntity> getAllByUserId(Long userId, String searchText) {
		List<DocCategoryEntity> docCategoryList = new ArrayList<>();
		//获取当前用户的角色
		List<Long> roleList = this.getUserRoleCache(userId);
		//获取有角色权限的分类
		QueryWrapper<DocCategoryRoleRelationEntity> queryWrapper = new QueryWrapper<>();
		queryWrapper.in("role_id", roleList);
		queryWrapper.eq("dr", 0);
		List<DocCategoryRoleRelationEntity> list = this.list(queryWrapper);
		if(CollectionUtils.isNotEmpty(list)){
			List<Long> categoryIds = new ArrayList<>();
			for(DocCategoryRoleRelationEntity entity : list){
				categoryIds.add(entity.getCategoryId());
			}
			QueryWrapper<DocCategoryEntity> wrapper = new QueryWrapper<>();
			wrapper.eq("dr", 0);
			wrapper.in("id", categoryIds);
			if(StringUtils.isNotBlank(searchText)) {
				wrapper.like("category_name", searchText);
			}
			docCategoryList = docCategoryService.list(wrapper);
		}
		return docCategoryList;
	}

	public List<Long> getUserRoleCache(Long userId) {
		List<Long> resultList = new ArrayList<Long>();
		String key = CURRENTUSER_ROLE_KEY + userId;
		Set<String> roleIds = cacheManager.execute(new CacheManager.JedisAction<Set<String>>() {
			@Override
			public Set<String> action(Jedis jedis) {
				return jedis.smembers(key);
			}
		});
		if(roleIds != null && !roleIds.isEmpty()) {
			for(String roleId:roleIds) {
				resultList.add(Long.parseLong(roleId));
			}
		}
		return resultList;
	}
}
